@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 from rez.package_repository import package_repository_manager
@@ -609,6 +598,24 @@ def get_package(name, version, paths=None):
         return None
 
 
+def get_package_family_from_repository(name, path):
+    """Get a package family from a repository.
+
+    Args:
+        name (str): Name of the package, eg 'maya'.
+
+    Returns:
+        `PackageFamily` object, or None if the family was not found.
+    """
+    repo = package_repository_manager.get_repository(path)
+
+    family_resource = repo.get_package_family(name)
+    if family_resource is None:
+        return None
+
+    return PackageFamily(family_resource)
+
+
 def get_package_from_repository(name, version, path):
     """Get a package from a repository.
 
