@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 """
@@ -160,6 +149,13 @@ class TestPipUtils(TestBase):
 
         self.assertTrue(rez.utils.pip.is_pure_python_package(dist))
 
+    def test_is_entry_points_scripts_package(self):
+        """
+        """
+        dpath = rez.vendor.distlib.database.DistributionPath([self.dist_path])
+        dist = list(dpath.get_distributions())[0]
+        self.assertFalse(rez.utils.pip.is_entry_points_scripts_package(dist))
+
     def test_convert_distlib_to_setuptools_wrong(self):
         """
         """
