@@ -1,16 +1,5 @@
-# Copyright Contributors to the Rez project
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
+# Copyright Contributors to the Rez Project
 
 
 from Qt import QtCore, QtWidgets
@@ -49,4 +38,4 @@ class AboutDialog(QtWidgets.QDialog):
 
     def _goto_github(self):
         import webbrowser
-        webbrowser.open_new("https://github.com/nerdvegas/rez")
+        webbrowser.open_new("https://github.com/AcademySoftwareFoundation/rez")
